@@ -1,12 +1,12 @@
-/*	SCCS Id: @(#)coord.h	3.2	90/02/22	*/
+/* NetHack 3.6	coord.h	$NHDT-Date: 1432512778 2015/05/25 00:12:58 $  $NHDT-Branch: master $:$NHDT-Revision: 1.9 $ */
 /* Copyright (c) Stichting Mathematisch Centrum, Amsterdam, 1985. */
 /* NetHack may be freely redistributed.  See license for details. */
 
 #ifndef COORD_H
 #define COORD_H
 
-typedef struct {
-	xchar x,y;
+typedef struct nhcoord {
+    xchar x, y;
 } coord;
 
 #endif /* COORD_H */
