@@ -1,10 +1,10 @@
-/*	SCCS Id: @(#)macconf.h	3.4	1999/10/25	*/
+/* NetHack 3.6	macconf.h	$NHDT-Date: 1432512782 2015/05/25 00:13:02 $  $NHDT-Branch: master $:$NHDT-Revision: 1.12 $ */
 /* Copyright (c) Stichting Mathematisch Centrum, Amsterdam, 1985. */
 /* NetHack may be freely redistributed.  See license for details. */
 
 #ifdef MAC
-# ifndef MACCONF_H
-#  define MACCONF_H
+#ifndef MACCONF_H
+#define MACCONF_H
 
 /*
  * Compiler selection is based on the following symbols:
@@ -23,15 +23,20 @@
  */
 
 #ifndef __powerc
-# define MAC68K		/* 68K mac (non-powerpc) */
+#define MAC68K /* 68K mac (non-powerpc) */
+#endif
+#ifndef TARGET_API_MAC_CARBON
+#define TARGET_API_MAC_CARBON 0
 #endif
 
+#ifndef __MACH__
 #define RANDOM
-#define NO_SIGNAL		/* You wouldn't believe our signals ... */
+#endif
+#define NO_SIGNAL /* You wouldn't believe our signals ... */
 #define FILENAME 256
-#define NO_TERMS		/* For tty port (see wintty.h) */
+#define NO_TERMS /* For tty port (see wintty.h) */
 
-#define TEXTCOLOR		/* For Mac TTY interface */
+#define TEXTCOLOR /* For Mac TTY interface */
 #define CHANGE_COLOR
 
 /* Use these two includes instead of system.h. */
@@ -40,13 +45,26 @@
 
 /* Uncomment this line if your headers don't already define off_t */
 /*typedef long off_t;*/
-#include <time.h>	/* for time_t */
+#include <time.h> /* for time_t */
 
 /*
  * Try and keep the number of files here to an ABSOLUTE minimum !
  * include the relevant files in the relevant .c files instead !
  */
+#if TARGET_API_MAC_CARBON
+#ifdef GNUC
+/* Avoid including <CarbonCore/fp.h> -- it has a conflicting expl() */
+#define __FP__
+#include <Carbon/Carbon.h>
+#else
+/* Avoid including <fenv.h> -- it uses GENERATINGPOWERPC */
+#define __FENV__
+#include <machine/types.h>
+#include <Carbon.h>
+#endif
+#else
 #include <MacTypes.h>
+#endif
 
 /*
  * We could use the PSN under sys 7 here ...
@@ -58,40 +76,44 @@
 #define rindex strrchr
 
 #define Rand random
-extern void error(const char *,...);
+extern void error(const char *, ...);
 
 #if !defined(O_WRONLY)
-# ifdef __MWERKS__
-#  include <unix.h>
-# endif
-# include <fcntl.h>
+#if defined(__MWERKS__) && !TARGET_API_MAC_CARBON
+#include <unix.h>
+#endif
+#include <fcntl.h>
 #endif
 
 /*
  * Don't redefine these Unix IO functions when making LevComp or DgnComp for
  * MPW.  With MPW, we make them into MPW tools, which use unix IO.  SPEC_LEV
- * and DGN_COMP are defined when compiling for LevComp and DgnComp respectively.
+ * and DGN_COMP are defined when compiling for LevComp and DgnComp
+ * respectively.
  */
-#if !((defined(__SC__) || defined(__MRC__)) && (defined(SPEC_LEV) || defined(DGN_COMP)))
-# define creat maccreat
-# define open macopen
-# define close macclose
-# define read macread
-# define write macwrite
-# define lseek macseek
-# define unlink _unlink
+#if !((defined(__SC__) || defined(__MRC__) || defined(__MACH__)) \
+      && (defined(SPEC_LEV) || defined(DGN_COMP)))
+#define creat maccreat
+#define open macopen
+#define close macclose
+#define read macread
+#define write macwrite
+#define lseek macseek
+#ifdef __MWERKS__
+#define unlink _unlink
+#endif
 #endif
 
-#define YY_NEVER_INTERACTIVE
+#define YY_NEVER_INTERACTIVE 1
 
-# define TEXT_TYPE 'TEXT'
-# define LEVL_TYPE 'LEVL'
-# define BONE_TYPE 'BONE'
-# define SAVE_TYPE 'SAVE'
-# define PREF_TYPE 'PREF'
-# define DATA_TYPE 'DATA'
-# define MAC_CREATOR 'nh31' /* Registered with DTS ! */
-# define TEXT_CREATOR 'ttxt' /* Something the user can actually edit */
+#define TEXT_TYPE 'TEXT'
+#define LEVL_TYPE 'LEVL'
+#define BONE_TYPE 'BONE'
+#define SAVE_TYPE 'SAVE'
+#define PREF_TYPE 'PREF'
+#define DATA_TYPE 'DATA'
+#define MAC_CREATOR 'nh31'  /* Registered with DTS ! */
+#define TEXT_CREATOR 'ttxt' /* Something the user can actually edit */
 
 /*
  * Define PORT_HELP to be the name of the port-specfic help file.
@@ -101,5 +123,5 @@ extern void error(const char *,...);
 
 #define MAC_GRAPHICS_ENV
 
-# endif /* ! MACCONF_H */
+#endif /* ! MACCONF_H */
 #endif /* MAC */
