@@ -1,4 +1,4 @@
-/*	SCCS Id: @(#)micro.h	3.3	90/02/22	*/
+/* NetHack 3.6	micro.h	$NHDT-Date: 1432512781 2015/05/25 00:13:01 $  $NHDT-Branch: master $:$NHDT-Revision: 1.9 $ */
 /* micro.h - function declarations for various microcomputers */
 /* NetHack may be freely redistributed.  See license for details. */
 
@@ -11,10 +11,10 @@ extern char levels[], bones[], permbones[], hackdir[];
 extern int ramdisk;
 
 #ifndef C
-#define C(c)	(0x1f & (c))
+#define C(c) (0x1f & (c))
 #endif
 #ifndef M
-#define M(c)	(0x80 | (c))
+#define M(c) (((char) 0x80) | (c))
 #endif
 #define ABORT C('a')
 
