@@ -1,4 +1,4 @@
-/*	SCCS Id: @(#)vmsconf.h	3.2	96/03/02	*/
+/* NetHack 3.6	vmsconf.h	$NHDT-Date: 1432512780 2015/05/25 00:13:00 $  $NHDT-Branch: master $:$NHDT-Revision: 1.22 $ */
 /* Copyright (c) Stichting Mathematisch Centrum, Amsterdam, 1985. */
 /* NetHack may be freely redistributed.  See license for details. */
 
@@ -15,8 +15,8 @@
  * Trailing NULs are present in the default values in order to make some
  *   extra room for patching longer values into an existing executable.
  */
-#define Local_WIZARD	"NHWIZARD\0\0\0\0"
-#define Local_HACKDIR	"DISK$USERS:[GAMES.NETHACK.3-2-0.PLAY]\0\0\0\0\0\0\0\0"
+#define Local_WIZARD "NHWIZARD\0\0\0\0"
+#define Local_HACKDIR "DISK$USERS:[GAMES.NETHACK.3_5_X.PLAY]\0\0\0\0\0\0\0\0"
 
 /*
  * This section cleans up the stuff done in config.h so that it
@@ -24,40 +24,37 @@
  * config.h is actually edited, the changes won't impact us.
  */
 #ifdef UNIX
-# undef UNIX
+#undef UNIX
 #endif
 #ifdef HACKDIR
-# undef HACKDIR
-#endif
-#ifdef WIZARD
-# undef WIZARD
+#undef HACKDIR
 #endif
 #ifdef WIZARD_NAME
-# undef WIZARD_NAME
+#undef WIZARD_NAME
 #endif
 #define HACKDIR Local_HACKDIR
-#ifndef KR1ED
-# define WIZARD Local_WIZARD
-# define WIZARD_NAME WIZARD
-#else
-# define WIZARD 1
-# define WIZARD_NAME Local_WIZARD
+#define WIZARD_NAME Local_WIZARD
+#ifndef SYSCF
+#define SYSCF
 #endif
 
 /* filenames require punctuation to avoid redirection via logical names */
 #undef RECORD
-#define RECORD	"record;1"	/* scoreboard file (retains high scores) */
+#define RECORD "record;1" /* scoreboard file (retains high scores) */
 #undef LOGFILE
-#define LOGFILE	"logfile;0"	/* optional file (records all games) */
+#define LOGFILE "logfile;0" /* optional file (records all games) */
+#undef SYSCF_FILE
+#define SYSCF_FILE "sysconf;0"
 
-#define HLOCK	"perm;1"	/* an empty file used for locking purposes */
+#define HLOCK "perm;1" /* an empty file used for locking purposes */
 
-/* want compression--for level & save files--performed within NetHack itself */
+/* want compression--for level & save files--performed within NetHack itself
+ */
 #ifdef COMPRESS
-# undef COMPRESS
+#undef COMPRESS
 #endif
 #ifndef INTERNAL_COMP
-# define INTERNAL_COMP
+#define INTERNAL_COMP
 #endif
 
 /*
@@ -66,13 +63,33 @@
  * of file protection fixups (protection of bones files and ownership of
  * save files).
  */
-/* #define SECURE /**/
+/* #define SECURE */
+
+/*
+ * If you use SECURE you'll need to link /noTraceback, in which case
+ * there's no point trying to get extra PANICTRACE info and this might
+ * as well be commented out.  When enabled, the sysconf file controls
+ * how to handle it (note that we're hijacking the Unix GDB setting):
+PANICTRACE_GDB=0  #behave as if PANICTRACE was disabled
+PANICTRACE_GDB=1  #at conclusion of panic, show a call traceback and exit
+PANICTRACE_GDB=2  #at conclusion of panic, show a call traceback and then
+ *                # remain in the debugger for more interactive debugging
+ *                # (not as useful as it might sound since we're normally
+ *                # linked /noDebug so there's no symbol table accessible)
+ */
+#define PANICTRACE
 
 /*
  * Put the readonly data files into a single container rather than into
  * separate files in the playground directory.
  */
-#define DLB	/* use data librarian code */
+#define DLB /* use data librarian code */
+
+/*
+ * Provide menu of saved games to choose from at start.
+ * [Player needs to use ``nethack "-ugames"'' for this to work.]
+ */
+#define SELECTSAVED
 
 /*
  * You may define TEXTCOLOR if your system has any terminals that recognize
@@ -83,13 +100,14 @@
  * color escape sequences, as do some 3rd party terminals and many micro
  * computers.
  */
-/* #define TEXTCOLOR /**/
+/* #define TEXTCOLOR */
 
 /*
  * If you define USE_QIO_INPUT, then you'll get raw characters from the
  * keyboard, not unlike those of the unix version of Nethack.  This will
  * allow you to use the Escape key in normal gameplay, and the appropriate
- * control characters in Wizard mode.  It will work most like the unix version.
+ * control characters in Wizard mode.  It will work most like the unix
+ * version.
  * It will also avoid "<interrupt>" being displayed when ^Y is pressed.
  *
  * Otherwise, the VMS SMG calls will be used.  These calls block use of
@@ -97,13 +115,13 @@
  * the same, although the differences are fairly negligible.  You must
  * then use a VTxxx function key or two <escape>s to give an ESC response.
  */
-#define USE_QIO_INPUT	/* use SYS$QIOW instead of SMG$READ_KEYSTROKE */
+#define USE_QIO_INPUT /* use SYS$QIOW instead of SMG$READ_KEYSTROKE */
 
 /*
  * Allow the user to decide whether to pause via timer or excess screen
  * output for various display effects like explosions and moving objects.
  */
-#define TIMED_DELAY	/* enable the `timed_delay' run-time option */
+#define TIMED_DELAY /* enable the `timed_delay' run-time option */
 
 /*
  * If you define MAIL, then NetHack will capture incoming broadcast
@@ -115,7 +133,7 @@
  * If you undefine MAIL, broadcasts will go straight to the terminal,
  * resulting in disruption of the screen display; use <ctrl/R> to redraw.
  */
-#define MAIL		/* enable broadcast trapping */
+#define MAIL /* enable broadcast trapping */
 
 /*
  * SHELL enables the player to 'escape' into a spawned subprocess via
@@ -127,12 +145,21 @@
  * to the parent process with the <ctrl/Z> command; this is not very
  * close to Unix job control, but it's better than nothing.
  */
-#define SHELL		/* do not delete the '!' command */
-#define SUSPEND		/* don't delete the ^Z command, such as it is */
+#define SHELL   /* do not delete the '!' command */
+#define SUSPEND /* don't delete the ^Z command, such as it is */
 
-#define RANDOM		/* use sys/share/random.c instead of vaxcrtl rand */
+/*
+ * Some terminals or terminal emulators send two character sequence "ESC c"
+ * when Alt+c is pressed.  The altmeta run-time option allows the user to
+ * request that "ESC c" be treated as M-c, which means that if nethack sees
+ * ESC when it is waiting for a command, it will wait for another character
+ * (even if user intended that ESC to be standalone to cancel a count prefix).
+ */
+#define ALTMETA /* support altmeta run-time option */
 
-#define FCMASK	0660	/* file creation mask */
+#define RANDOM /* use sys/share/random.c instead of vaxcrtl rand */
+
+#define FCMASK 0660 /* file creation mask */
 
 /*
  * The remainder of the file should not need to be changed.
@@ -140,107 +167,113 @@
 
 /* data librarian defs */
 #ifdef DLB
-# define DLBFILE	"nh-data.dlb"
-	/*
-	 * Since we can do without case insensitive filename comparison,
-	 * avoid enabling it because that requires compiling and linking
-	 * src/hacklib into util/dlb_main.
-	 */
-/* # define FILENAME_CMP	strcmpi	/* case insensitive */
+#define DLBFILE "nh-data.dlb"
+/*
+ * Since we can do without case insensitive filename comparison,
+ * avoid enabling it because that requires compiling and linking
+ * src/hacklib into util/dlb_main.
+ */
+/* # define FILENAME_CMP strcmpi */ /* case insensitive */
 #endif
 
 #if defined(VAXC) && !defined(ANCIENT_VAXC)
-# ifdef volatile
-#  undef volatile
-# endif
-# ifdef const
-#  undef const
-# endif
+#ifdef volatile
+#undef volatile
+#endif
+#ifdef const
+#undef const
+#endif
 #endif
 
 #ifdef __DECC
-# define STRICT_REF_DEF	/* used in lev_main.c */
+#define STRICT_REF_DEF /* used in lev_main.c */
 #endif
 #ifdef STRICT_REF_DEF
-# define DEFINE_OSPEED
+#define DEFINE_OSPEED
 #endif
 
 #ifndef alloca
-	/* bison generated foo_yacc.c might try to use alloca() */
-# ifdef __GNUC__
-#  define alloca __builtin_alloca
-# else
-#  define ALLOCA_HACK	/* used in util/panic.c */
-# endif
+/* bison generated foo_yacc.c might try to use alloca() */
+#ifdef __GNUC__
+#define alloca __builtin_alloca
+#else
+#define ALLOCA_HACK /* used in util/panic.c */
+#endif
 #endif
 
 #ifdef _DECC_V4_SOURCE
-/* <types.h> excludes some necessary typedefs when _DECC_V4_SOURCE is defined */
+/* <types.h> excludes some necessary typedefs when _DECC_V4_SOURCE is defined
+ */
 #include <types.h>
-# ifndef __PID_T
-# define __PID_T
+#ifndef __PID_T
+#define __PID_T
 typedef __pid_t pid_t;
-# endif
-# ifndef __UID_T
-# define __UID_T
+#endif
+#ifndef __UID_T
+#define __UID_T
 typedef __uid_t uid_t;
-# endif
-# ifndef __GID_T
-# define __GID_T
+#endif
+#ifndef __GID_T
+#define __GID_T
 typedef __gid_t gid_t;
-# endif
-#endif	/* _DECC_V4_SOURCE */
+#endif
+#ifndef __MODE_T
+#define __MODE_T
+typedef __mode_t mode_t;
+#endif
+#endif /* _DECC_V4_SOURCE */
 
 #include <time.h>
-#if 0	/* <file.h> is missing for old gcc versions; skip it to save time */
+#if 0 /* <file.h> is missing for old gcc versions; skip it to save time */
 #include <file.h>
-#else	/* values needed from missing include file */
-# define O_RDONLY 0
-# define O_WRONLY 1
-# define O_RDWR   2
-# define O_CREAT 0x200
-# define O_TRUNC 0x400
+#else /* values needed from missing include file */
+#define O_RDONLY 0
+#define O_WRONLY 1
+#define O_RDWR 2
+#define O_CREAT 0x200
+#define O_TRUNC 0x400
 #endif
 
-#ifndef REDO
-# define Getchar nhgetch
-#endif
 #define tgetch vms_getchar
 
 #include "system.h"
 
-#define index	strchr
-#define rindex	strrchr
+#define index strchr
+#define rindex strrchr
 
 /* Use the high quality random number routines. */
 #if defined(RANDOM)
-#define Rand()	random()
+#define Rand() random()
 /* VMS V7 adds these entry points to DECC$SHR; stick with the nethack-supplied
-   code to avoid having to deal with version-specific conditionalized builds */
-#define random		nh_random
-#define srandom		nh_srandom
-#define initstate	nh_initstate
-#define setstate	nh_setstate
+   code to avoid having to deal with version-specific conditionalized builds
+   */
+#define random nh_random
+#define srandom nh_srandom
+#define initstate nh_initstate
+#define setstate nh_setstate
 #else
-#define Rand()	rand()
+#define Rand() rand()
 #endif
 
 #ifndef __GNUC__
-#define bcopy(s,d,n)	memcpy((d),(s),(n))	/* vaxcrtl */
+#ifndef bcopy
+#define bcopy(s, d, n) memcpy((d), (s), (n)) /* vaxcrtl */
 #endif
-#define abort()		vms_abort()		/* vmsmisc.c */
-#define creat(f,m)	vms_creat(f,m)		/* vmsfiles.c */
-#define exit(sts)	vms_exit(sts)		/* vmsmisc.c */
-#define getuid()	vms_getuid()		/* vmsunix.c */
-#define link(f1,f2)	vms_link(f1,f2)		/* vmsfiles.c */
-#define open(f,k,m)	vms_open(f,k,m)		/* vmsfiles.c */
+#endif
+#define abort() vms_abort()             /* vmsmisc.c */
+#define creat(f, m) vms_creat(f, m)     /* vmsfiles.c */
+#define exit(sts) vms_exit(sts)         /* vmsmisc.c */
+#define getuid() vms_getuid()           /* vmsunix.c */
+#define link(f1, f2) vms_link(f1, f2)   /* vmsfiles.c */
+#define open(f, k, m) vms_open(f, k, m) /* vmsfiles.c */
+#define fopen(f, m) vms_fopen(f, m)     /* vmsfiles.c */
 /* #define unlink(f0)	vms_unlink(f0)		/* vmsfiles.c */
 #ifdef VERYOLD_VMS
-#define unlink(f0)	delete(f0)		/* vaxcrtl */
+#define unlink(f0) delete (f0) /* vaxcrtl */
 #else
-#define unlink(f0)	remove(f0)		/* vaxcrtl, decc$shr */
+#define unlink(f0) remove(f0) /* vaxcrtl, decc$shr */
 #endif
-#define C$$TRANSLATE(n)	c__translate(n)		/* vmsfiles.c */
+#define C$$TRANSLATE(n) c__translate(n) /* vmsfiles.c */
 
 /* VMS global names are case insensitive... */
 #define An vms_an
@@ -252,7 +285,9 @@ typedef __gid_t gid_t;
 
 /* used in several files which don't #include "extern.h" */
 extern void FDECL(vms_exit, (int));
-extern int FDECL(vms_open, (const char *,int,unsigned));
+extern int FDECL(vms_open, (const char *, int, unsigned));
+extern FILE *FDECL(vms_fopen, (const char *, const char *));
+char *FDECL(vms_basename, (const char *)); /* vmsfiles.c */
 
-#endif	/* VMSCONF_H */
-#endif	/* VMS */
+#endif /* VMSCONF_H */
+#endif /* VMS */
