@@ -1,4 +1,4 @@
-/*	SCCS Id: @(#)gnomeprv.h	3.4	2000/07/16	*/
+/* NetHack 3.6	gnomeprv.h	$NHDT-Date: 1432512806 2015/05/25 00:13:26 $  $NHDT-Branch: master $:$NHDT-Revision: 1.9 $ */
 /* Copyright (C) 1998 by Erik Andersen <andersee@debian.org> */
 /* NetHack may be freely redistributed.  See license for details. */
 
@@ -10,7 +10,6 @@
 #include "dlb.h"
 #include "patchlevel.h"
 
-#endif    /* GnomeHack_h */
-
-
+#include "winGnome.h"
 
+#endif /* GnomeHack_h */
