@@ -1,14 +1,15 @@
+/* NetHack 3.6  tile.h       $NHDT-Date: 1432512803 2015/05/25 00:13:23 $  $NHDT-Branch: master $:$NHDT-Revision: 1.10 $ */
 typedef unsigned char pixval;
 
-typedef struct {
+typedef struct pixel_s {
     pixval r, g, b;
 } pixel;
 
-#define MAXCOLORMAPSIZE 	256
+#define MAXCOLORMAPSIZE 256
 
-#define CM_RED		0
-#define CM_GREEN	1
-#define CM_BLUE 	2
+#define CM_RED 0
+#define CM_GREEN 1
+#define CM_BLUE 2
 
 /* shared between reader and writer */
 extern pixval ColorMap[3][MAXCOLORMAPSIZE];
@@ -17,7 +18,7 @@ extern int colorsinmap;
 extern pixval MainColorMap[3][MAXCOLORMAPSIZE];
 extern int colorsinmainmap;
 
-#include "dlb.h"	/* for MODEs */
+#include "dlb.h" /* for MODEs */
 
 /* size of tiles */
 #ifndef TILE_X
@@ -29,18 +30,17 @@ extern int colorsinmainmap;
 
 #define Fprintf (void) fprintf
 
-
 extern boolean FDECL(fopen_text_file, (const char *, const char *));
-extern boolean FDECL(read_text_tile, (pixel (*)[TILE_X]));
-extern boolean FDECL(write_text_tile, (pixel (*)[TILE_X]));
+extern boolean FDECL(read_text_tile, (pixel(*) [TILE_X]));
+extern boolean FDECL(write_text_tile, (pixel(*) [TILE_X]));
 extern int NDECL(fclose_text_file);
 
 extern void NDECL(init_colormap);
 extern void NDECL(merge_colormap);
 
-#if defined(MICRO)
+#if defined(MICRO) || defined(WIN32)
 #undef exit
-# if !defined(MSDOS) && !defined(WIN32)
+#if !defined(MSDOS) && !defined(WIN32)
 extern void FDECL(exit, (int));
-# endif
+#endif
 #endif
